@@ -20,4 +20,8 @@ class test_read(unittest.TestCase):
         else:
             num = 12
         py_x = {'__tlist_name': 'test', 'a': num, 'b': ['item']}
-        assert x == py_x, str(py_x) + " != tlist(['test','a','b'],12,'item')"
\ No newline at end of file
+        assert x == py_x, str(py_x) + " != tlist(['test','a','b'],12,'item')"
+
+if __name__ == '__main__':
+	unittest.main()
+
