@@ -1,15 +1,16 @@
 #ifndef _UTIL_H
 #define _UTIL_H
 
-#undef HAVE_STRERRO
+#undef HAVE_STRERROR
 #undef SIZEOF_LONG
 
-#include "stack-c-4py.h"
-#include "CallScilab.h"
-#include "stack-c.h"
+#include "call_scilab.h"
+#include "api_scilab.h"
 
 #define BUFSIZE 1024
 
+#define TLIST_NAME	"__tlist_name"
+
 /*
  * This has to be defined when a numpy extension
  * is split accross multiple files
